#[non_exhaustive]pub enum DieselError {
InvalidCString(NulError),
DatabaseError(DatabaseErrorKind, Box<dyn DatabaseErrorInformation + Sync + Send>),
NotFound,
QueryBuilderError(Box<dyn Error + Sync + Send>),
DeserializationError(Box<dyn Error + Sync + Send>),
SerializationError(Box<dyn Error + Sync + Send>),
RollbackErrorOnCommit {
rollback_error: Box<Error>,
commit_error: Box<Error>,
},
RollbackTransaction,
AlreadyInTransaction,
NotInTransaction,
BrokenTransactionManager,
}Expand description
Represents all the ways that a query can fail.
This type is not intended to be exhaustively matched, and new variants may be added in the future without a major version bump.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidCString(NulError)
The query contained a nul byte.
This should never occur in normal usage.
DatabaseError(DatabaseErrorKind, Box<dyn DatabaseErrorInformation + Sync + Send>)
The database returned an error.
While Diesel prevents almost all sources of runtime errors at compile time, it does not attempt to prevent 100% of them. Typically this error will occur from insert or update statements due to a constraint violation.
NotFound
No rows were returned by a query expected to return at least one row.
This variant is only returned by get_result and first. load
does not treat 0 rows as an error. If you would like to allow either 0
or 1 rows, call optional on the result.
QueryBuilderError(Box<dyn Error + Sync + Send>)
The query could not be constructed
An example of when this error could occur is if you are attempting to
construct an update statement with no changes (e.g. all fields on the
struct are None).
DeserializationError(Box<dyn Error + Sync + Send>)
An error occurred deserializing the data being sent to the database.
Typically this error means that the stated type of the query is incorrect. An example of when this error might occur in normal usage is attempting to deserialize an infinite date into chrono.
SerializationError(Box<dyn Error + Sync + Send>)
An error occurred serializing the data being sent to the database.
An example of when this error would be returned is if you attempted to
serialize a chrono::NaiveDate earlier than the earliest date supported
by PostgreSQL.
RollbackErrorOnCommit
An error occurred when attempting rollback of a transaction subsequently to a failed commit attempt.
When a commit attempt fails and Diesel believes that it can attempt a rollback to return the connection back in a usable state (out of that transaction), it attempts it then returns the original error.
If that fails, you get this.
Fields
RollbackTransaction
Roll back the current transaction.
You can return this variant inside of a transaction when you want to roll it back, but have no actual error to return. Diesel will never return this variant unless you gave it to us, and it can be safely ignored in error handling.
AlreadyInTransaction
Attempted to perform an operation that cannot be done inside a transaction when a transaction was already open.
NotInTransaction
Attempted to perform an operation that can only be done inside a transaction when no transaction was open
BrokenTransactionManager
Transaction manager broken, likely due to a broken connection. No other operations are possible.